;; Generated package description from project.el  -*- no-byte-compile: t -*-
(define-package "project" "0.9.8.0.20230903.1223" "Operations on the current project" '((emacs "26.1") (xref "1.4.0")) :commit "7e03fa2d8291473dac585eeae5e3f710600595c6" :url "https://elpa.gnu.org/packages/project.html")
